@@ -37,6 +37,7 @@ from zc.buildout.configparser import (
     option_start,
     section_header,
 )
+import requests
 from . import recipes
 from . import jinja
 
@@ -44,6 +45,7 @@ from pygls.server import LanguageServer
 from pygls.types import Position, Range, Location
 
 logger = logging.getLogger(__name__)
+requests_session = requests.Session()
 
 # Matches a reference like ${section:option}
 # We also tolerate ${section: without option or the ending } to generate completions.
@@ -298,21 +300,24 @@ class BuildoutTemplate:
       option_reference_match = option_reference_re.match(remaining_line)
       section_reference_match = section_reference_re.match(remaining_line)
       if option_reference_match:
-        logger.debug("got an option_reference_match %s", option_reference_match)
+        logger.debug("got an option_reference_match %s",
+                     option_reference_match)
         referenced_buildout = self.buildout
-        if (option_reference_match.start() + line_offset > 0 and
-            line[option_reference_match.start() + line_offset - 1] == '$'):
+        if (option_reference_match.start() + line_offset > 0
+            and line[option_reference_match.start() + line_offset - 1] == '$'):
           if self.second_level_buildout:
             referenced_buildout = self.second_level_buildout
           else:
             return None
 
         if (option_reference_match.start() <=
-            (position.character - line_offset) <= option_reference_match.end()):
+            (position.character - line_offset) <=
+            option_reference_match.end()):
           # the position is in ${section:option}, find out wether it is in section or option
-          position_on_option = (
-              line_offset + option_reference_match.start() + len('${') +
-              len(option_reference_match.group('section'))) < position.character
+          position_on_option = (line_offset + option_reference_match.start() +
+                                len('${') +
+                                len(option_reference_match.group('section'))
+                                ) < position.character
           referenced_section_name = option_reference_match.group('section')
           referenced_option_name = option_reference_match.group('option')
 
@@ -324,8 +329,8 @@ class BuildoutTemplate:
               if position_on_option else referenced_section_name,
               current_section_name=current_section_name,
               current_option_name=current_option_name,
-              referenced_section_name=referenced_section_name or
-              current_section_name,
+              referenced_section_name=referenced_section_name
+              or current_section_name,
               is_same_section_reference=referenced_section_name == '',
               referenced_option_name=referenced_option_name,
           )
@@ -354,8 +359,8 @@ class BuildoutTemplate:
               value=referenced_section_name,
               current_section_name=current_section_name,
               current_option_name=current_option_name,
-              referenced_section_name=referenced_section_name or
-              current_section_name,
+              referenced_section_name=referenced_section_name
+              or current_section_name,
               is_same_section_reference=referenced_section_name == '',
           )
         else:
@@ -431,6 +436,9 @@ class BuildoutProfile(Dict[str, BuildoutSection], BuildoutTemplate):
                                         Location] = collections.OrderedDict()
     """The locations for each section, keyed by section names.
     """
+    self.extends_jinja = False
+    """Flag true if this resolved buildout had extends defined by jinja expressions.
+    """
 
   async def getTemplate(
       self,
@@ -446,7 +454,7 @@ class BuildoutProfile(Dict[str, BuildoutSection], BuildoutTemplate):
 
     # uri can be passed as relative or absolute. Let's build a set of absolute
     # and relative uris.
-    uris = set((uri,))
+    uris = set((uri, ))
 
     if not _isurl(uri):
       base = self.uri[:self.uri.rfind('/')] + '/'
@@ -482,7 +490,8 @@ class BuildoutProfile(Dict[str, BuildoutSection], BuildoutTemplate):
                            template_option_value_uri, section_value_dict)
 
               def expand_section_reference(match: Match[str]) -> str:
-                referenced_section_name = match.group('section') or section_name
+                referenced_section_name = match.group(
+                    'section') or section_name
                 if referenced_section_name in self:
                   referenced_section = self[referenced_section_name]
                   if match.group('option') in referenced_section:
@@ -606,8 +615,9 @@ class BuildoutProfile(Dict[str, BuildoutSection], BuildoutTemplate):
                 line_offset + option_value_definition_match.start() +
                 len(option_value_definition_match.group('option')))
 
-            logger.debug("option_value_definition_match, position on option %s",
-                         position_on_option)
+            logger.debug(
+                "option_value_definition_match, position on option %s",
+                position_on_option)
             return Symbol(
                 kind=SymbolKind.BuildoutOptionKey
                 if position_on_option else SymbolKind.BuildoutOptionValue,
@@ -741,8 +751,8 @@ class BuildoutProfile(Dict[str, BuildoutSection], BuildoutTemplate):
   def looksLikeBuildoutProfile(uri: URI) -> bool:
     """Check if this URI looks like a buildout profile URI.
     """
-    return (uri.endswith('.cfg') or uri.endswith('.cfg.in') or
-            uri.endswith('.cfg.j2') or uri.endswith('.cfg.jinja2'))
+    return (uri.endswith('.cfg') or uri.endswith('.cfg.in')
+            or uri.endswith('.cfg.j2') or uri.endswith('.cfg.jinja2'))
 
 
 class ResolvedBuildout(BuildoutProfile):
@@ -811,13 +821,23 @@ async def parse(
   if uri in _parse_cache:
     return copy.deepcopy(_parse_cache[uri])
 
-  document = ls.workspace.get_document(uri)
-  try:
-    fp = io.StringIO(document.source)
-  except IOError:
-    if not allow_errors:
-      raise
-    fp = io.StringIO('')
+  parsed_uri = urllib.parse.urlparse(uri)
+  if parsed_uri.scheme in (
+      'http',
+      'https',
+  ):
+    try:
+      fp = io.StringIO(requests_session.get(uri).text)
+    except requests.exceptions.ConnectionError:
+      fp = io.StringIO('')
+  else:
+    document = ls.workspace.get_document(uri)
+    try:
+      fp = io.StringIO(document.source)
+    except IOError:
+      if not allow_errors:
+        raise
+      fp = io.StringIO('')
   parsed = await _parse(
       fp,
       uri,
@@ -876,8 +896,8 @@ async def _parse(
   if slapos_instance_profile_filename_re.match(uri):
     # Add slapos instance generated sections.
     sections.section_header_locations.setdefault(
-        'slap-connection',
-        Location(uri='', range=Range(Position(), Position())))
+        'slap-connection', Location(uri='',
+                                    range=Range(Position(), Position())))
     slap_connection = BuildoutSection()
     for k in (
         'computer-id',
@@ -929,6 +949,7 @@ async def _parse(
     jinja_parser.feed(line)
     if jinja_parser.is_in_jinja:
       continue
+    line = jinja_parser.line
 
     if line[0] in '#;':
       continue  # comment
@@ -955,7 +976,8 @@ async def _parse(
       if header:
         sectname = header.group('name')
         sections.section_header_locations[sectname] = Location(
-            uri=uri, range=Range(
+            uri=uri,
+            range=Range(
                 Position(lineno, 0),
                 Position(lineno + 1, 0),
             ))
@@ -966,8 +988,8 @@ async def _parse(
           # initialize buildout default options
           cursect['_buildout_section_name_'] = BuildoutOptionDefinition(
               locations=[
-                  Location(
-                      uri=uri, range=Range(Position(0, 0), Position(0, 0)))
+                  Location(uri=uri,
+                           range=Range(Position(0, 0), Position(0, 0)))
               ],
               value=sectname,
               implicit_option=True,
@@ -978,8 +1000,8 @@ async def _parse(
             base_location = uri[:uri.rfind('/')] + '/'
           cursect['_profile_base_location_'] = BuildoutOptionDefinition(
               locations=[
-                  Location(
-                      uri=uri, range=Range(Position(0, 0), Position(0, 0)))
+                  Location(uri=uri,
+                           range=Range(Position(0, 0), Position(0, 0)))
               ],
               value=base_location,
               implicit_option=True,
@@ -1009,13 +1031,12 @@ async def _parse(
           option_def.value = optval
 
           option_def.locations.append(
-              Location(
-                  uri=uri,
-                  range=Range(
-                      start=Position(
-                          line=lineno, character=len(mo.groups()[0]) + 1),
-                      end=Position(line=lineno, character=len(line) - 1),
-                  )))
+              Location(uri=uri,
+                       range=Range(
+                           start=Position(line=lineno,
+                                          character=len(mo.groups()[0]) + 1),
+                           end=Position(line=lineno, character=len(line) - 1),
+                       )))
           option_def.implicit_option = False
           cursect[optname] = option_def
           blockmode = not optval
@@ -1148,13 +1169,15 @@ async def _open(
 
   extends_option = result['buildout'].pop(
       'extends', None) if 'buildout' in result else None
-
+  extends_jinja = False
   if extends_option:
     extends = extends_option.value.split()
+    extends_jinja = (jinja.JinjaParser.jinja_value in extends)
     if extends:
       # extends, as absolute URI that we can use as cache key
       absolute_extends = tuple(urllib.parse.urljoin(base, x) for x in extends)
       eresult = await _open(ls, base, extends.pop(0), seen, allow_errors)
+      extends_jinja = extends_jinja or eresult.extends_jinja
       for fname in extends:
         _update(eresult, await _open(ls, base, fname, seen, allow_errors))
       for absolute_extend in absolute_extends:
@@ -1177,6 +1200,7 @@ async def _open(
         # this happens with non top-level buildout
         pass
 
+  result.extends_jinja = extends_jinja
   resolved = cast(ResolvedBuildout, result)
   _resolved_buildout_cache[uri] = resolved
   return copy.deepcopy(resolved)
@@ -1195,9 +1219,9 @@ def _update_section(
       # Find v1 in s2 first; it may have been set by a += operation first
       option_def = s2.get(k, s1.get(k, v))
       # same logic as as SectionKey.removeFromValue
-      option_def.value = '\n'.join(
-          new_v for new_v in option_def.value.split('\n')
-          if new_v not in v.value.split('\n'))
+      option_def.value = '\n'.join(new_v
+                                   for new_v in option_def.value.split('\n')
+                                   if new_v not in v.value.split('\n'))
       option_def.locations.extend(v.locations)
       s1[k] = option_def
     elif k.endswith('+'):
